@@ -12,10 +12,11 @@ zoo <- function (x, order.by = index(x), frequency = NULL)
         x <- (x[rep(1:NROW(x), length.out = length(index)), , 
             drop = FALSE])[index, , drop = FALSE]
     else stop(paste(dQuote("x"), ": attempt to define illegal zoo object"))
+    if(is.matrix(x) || is.data.frame(x)) x <- as.matrix(x)
 
     if(!is.null(frequency)) {
         d <- try(diff(as.numeric(order.by)))
-	ok <- if(class(d) == "try-error") FALSE
+	ok <- if(class(d) == "try-error" || length(d) < 1) FALSE
 	else {	    
             deltat <- min(d)
 	    dd <- d/deltat
